pub enum KafkaProducerError {
InvalidConfig(KafkaError),
SendFailed(KafkaError),
FlushFailed(KafkaError),
}Expand description
Something that went wrong producing to Kafka.
Variants
InvalidConfig(KafkaError)
The producer could not be created from the given configuration.
SendFailed(KafkaError)
The record could not be enqueued.
This may mean the local queue is full, which may be caused by the broker being unreachable or backed up.
FlushFailed(KafkaError)
The local queue was not emptied before the flush timeout elapsed.